import nazca as nd
from nazca.clipper import merge_polygons, grow_polygons, diff_polygons

spc = 250

boat  = [(0,0), (121,0), (131,41), (-11, 41)]
sail  = [(31,51), (101,35), (81,151)]
sun   = [(x+30,y+140) for x,y in nd.geometries.circle(radius=20)]

# Show originals
nd.Polygon(layer=1,  points=boat).put()
nd.Polygon(layer=3,  points=sail).put()
nd.Polygon(layer=60, points=sun).put()

bss_merge = merge_polygons([boat, sail, sun])

# Show result of merge
for poly in bss_merge:
    nd.Polygon(layer=5, points=poly).put(spc)

bss_grow = grow_polygons(bss_merge)

# Show result of grow with defaults (5 µm grow, 0.1 µm grid)
for poly in bss_grow:
    nd.Polygon(layer=5, points=poly).put(0, -spc)

bss_grow = grow_polygons(bss_merge, grow=15, accuracy=0.01)

# Show result of grow with 15 µm grow on 0.01 µm grid
for poly in bss_grow:
    nd.Polygon(layer=5, points=poly).put(spc, -spc)

bss_grow = grow_polygons(bss_merge, jointype='miter')

# Show result of grow with defaults (5 µm grow, 0.1 µm grid)
for poly in bss_grow:
    nd.Polygon(layer=5, points=poly).put(0, -2*spc)

bss_grow = grow_polygons(bss_merge, grow=15, accuracy=0.01,
        jointype='miter')

# Show result of grow with 15 µm grow on 0.01 µm grid
for poly in bss_grow:
    nd.Polygon(layer=5, points=poly).put(spc, -2*spc)

bss_grow = grow_polygons(bss_merge, jointype='square')

# Show result of grow with defaults (5 µm grow, 0.1 µm grid)
for poly in bss_grow:
    nd.Polygon(layer=5, points=poly).put(0, -3*spc)

bss_grow = grow_polygons([boat], grow=15, accuracy=0.01,
        jointype='square')

# Show result of grow with 15 µm grow on 0.01 µm grid
for poly in bss_grow:
    nd.Polygon(layer=5, points=poly).put(spc, -3*spc)

# Difference
bss_diff = diff_polygons(bss_grow, bss_merge)

for poly in bss_diff:
    nd.Polygon(layer=6, points=poly).put(2* spc, -3*spc)

nd.export_plt()
