#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Example file to test interconnects.

Created on Sat Dec 31 22:00:04 2016

@author: rgb
"""


import nazca as nd
import nazca.demofab.pdk as sp
import nazca.interconnects as IC

ics = IC.Interconnect(xs='Shallow', radius=50, width=2.0)
icd = IC.Interconnect(xs='Deep', radius=30, width=1.5)

XSshal = nd.get_xsection('Shallow')
XSdeep = nd.get_xsection('Deep')

XSshal.os = 0.20
XSdeep.os = 0.10

ss = ics.strt(50)
sd = icd.strt(50)


with nd.Cell('strt_p2p') as D1:
    a1 = ss.put()
    a2 = ss.put(200, -200, 0)
    ics.strt_p2p(a1.pin['b0'], a2.pin['a0']).put()


with nd.Cell('sbend') as D2:
    nd.bbinfo(item='provider', data='Bright Photonics')
    nd.bbinfo(item='license', data='Bright Photonics')
    nd.bbinfo(item='version', data='Bright Photonics')

    a1 = ss.put(0)
    sb = icd.sbend(radius=30, offset=80, Ltot=-150)
    sb.put()


with nd.Cell('sbend_p2p') as D3:
    a1 = ss.put(0)
    a2 = ss.put(400, -200, 0)
    sb = icd.sbend_p2p(
        a1.pin['b0'],
        a2.pin['a0'],
        Lstart=50)
    sb.put()


with nd.Cell('bend_strt_bend_p2p') as D4:
    a1 = ss.put(0)
    a2 = ss.put(200, -200, 40)
    ics.bend_strt_bend_p2p(
        a1.pin['a0'],
        a2.pin['b0'],
        radius1=40,
        radius2=80,
        ictype='all' # 'all', 'shortest', 'rr', 'rl', 'lr', 'll'
        ).put()


with nd.Cell('bend_strt_bend_p2p') as D4b:
    a1 = ss.put(0)
    p1 = nd.Pin().put(100, -100, 45)
    p2 = nd.Pin().put(200, -100, -45)
    ics.bend_strt_bend_p2p(p1).put()
    ics.bend_strt_bend_p2p(p1.move(100, -100, -30)).put()


with nd.Cell('strt_bend_strt_p2p') as D5:
    a1 = ss.put()
    a2 = ss.put(200, -200, -100)
    icd.strt_bend_strt_p2p(
        pin1=a1.pin['b0'],
        pin2=a2.pin['a0'],
        radius=40
        ).put()


with nd.Cell('reuse_ic') as D6:
    p = []
    p.append(nd.Pin().put(100, 100, -100))
    p.append(nd.Pin().put(400, 100, 100))
    I = ics.strt_bend_strt_p2p(p[0], p[1])
    I.put()
    I.put()
    I.put()
    I.put()
    I.put((-100,100,90))


with nd.Cell('ubend') as D7:
    a1 = ss.put(0)
    a2 = ss.put(200, -200, 0)
    ub = ics.ubend_p2p(
        pin1=a1.pin['b0'],
        pin2=a2.pin['b0'],
        length=30
        ).put()
    sb = ics.bend_strt_bend_p2p(
        pin1=a1.pin['a0'],
        pin2=a2.pin['a0'],
        width=10
        ).put()


nd.export_gds([D1, D2, D3, D4, D4b, D5, D6, D7])

print(D2.bbinfo)