#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Example of autoadapting Interconnects.

@author: rgb
"""

import random
from math import sin, cos, pi

import nazca as nd
import nazca.interconnects as IC
import nazca.demofab.pdk as demo


nd.get_xsection('Shallow').os = 0.1
nd.get_xsection('Shallow').radius = 50

nd.get_xsection('Deep').os = 0.02
nd.get_xsection('Deep').radius = 30

demo.xsMetalDC.os = 0
nd.get_xsection('MetalDC').radius = 20

icadapt = IC.Interconnect(xs='Shallow', adapt_width=True, adapt_xs=True)


# make BB with various pins
with nd.Cell('adapt3') as C1:
    R = 45
    N = 8
    xslist = ['Shallow', 'Deep', 'MetalDC']
    for i in range(N):
        xs  = xslist[random.randrange(0, 3, 1)]
        width = random.randrange(1, 10, 1)
        a = pi*2*i/float(N)
        nd.Pin('a'+str(i), xs=xs, width=width).put(R*cos(a), R*sin(a), 360*i/N)


with nd.Cell('sun') as Sun:
    points = [(0, 0), (0, 20), (50, 100), (-100, 80), (100, 200), (0, 350)]
    I = C1.put(0)
    for name, p in I.pin.items():
        if 'a' in name:
            b = icadapt.taper(pin=p).put()
            icadapt.mamba(points=points, polyline=False).put(b.pin['b0'])


for i in range(3):
    for j in range(3):
        Sun.put('org', i*900, j*900)


#nd.export_gds()
nd.set_plt_properties(figsize=20)
nd.export_plt([Sun])

