#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Example on defining an MZI.

copyright ronald broeke
"""

import sys
print ('\n'.join(sys.path))

import nazca as nd
import nazca.interconnects as IC
import nazca.demofab.pdk as demo

nd.set_plt_properties(figsize=10, cmap='Set3', N=24, alpha=0.5)

icd = IC.Interconnect(xs='Deep', width=1.5, radius=100)
icm = IC.Interconnect(xs='MetalDC', width=20, radius=20)

eopm = demo.eopm_dc(length=1000, contacts=1)
mmi =  demo.mmi1x2_dp()

#part 1
left_mmi = mmi.put()
top_eopm = eopm.put(left_mmi.pin['b0'].move(135, 50))
bot_eopm = eopm.put(left_mmi.pin['b1'].move(135, -50), flip=True)
right_mmi = mmi.put('b1', top_eopm.pin['b0'].move(135, -50))
nd.export_plt(clear=False, title='1. place BBs')

#part 2
icd.sbend_p2p(left_mmi.pin['b0'], top_eopm.pin['a0']).put()
icd.sbend_p2p(top_eopm.pin['b0'], right_mmi.pin['b1']).put()
nd.export_plt(clear=False, title='2. interconnect top')

#part 3
icd.sbend_p2p(left_mmi.pin['b1'], bot_eopm.pin['a0']).put()
icd.sbend_p2p(bot_eopm.pin['b0'], right_mmi.pin['b0']).put()
nd.export_plt(clear=False, title='3. interconnect bottom')

#part 4
nd.Pin('a0').put(left_mmi.pin['a0'])
nd.Pin('b0').put(right_mmi.pin['a0'])
nd.Pin('c0').put(top_eopm.pin['c0'])
nd.Pin('c1').put(bot_eopm.pin['c0'])

icm.strt(length=20).put(top_eopm.pin['c0'])
icm.bend().put()
icm.strt(length=20).put(bot_eopm.pin['c0'])
icm.bend().put()
nd.export_plt(clear=False, title='4. MZI ready')

nd.export_gds()
