#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Example on defining an MZI.

copyright ronald broeke
"""

import sys
print ('\n'.join(sys.path))

import nazca as nd
import nazca.interconnects as IC
import nazca.demofab.pdk as demo

nd.set_plt_properties(figsize=10, cmap='Set3', N=24, alpha=0.5)

adapt = IC.Interconnect(adapt_xs=True, adapt_width=True)
icd = IC.Interconnect(xs='Deep', width=1.5, radius=100)
icm = IC.Interconnect(xs='Metal', width=20, radius=20)

with nd.Cell('mzi') as mziBB:
    eopm = demo.eopm_dc(length=1000, contacts=1, pads=True)
    mmi =  demo.mmi1x2_dp()

    #part 1: BBs
    left_mmi = mmi.put()
    top_eopm = eopm.put(left_mmi.pin['b0'].move(135, 50))
    bot_eopm = eopm.put(left_mmi.pin['b1'].move(135, -50), flip=True)
    right_mmi = mmi.put('b1', top_eopm.pin['b0'].move(135, -50))

    #part 2: top connections
    icd.sbend_p2p(left_mmi.pin['b0'], top_eopm.pin['a0']).put()
    icd.sbend_p2p(top_eopm.pin['b0'], right_mmi.pin['b1']).put()

    #part 3: bottom connections
    icd.sbend_p2p(left_mmi.pin['b1'], bot_eopm.pin['a0']).put()
    icd.sbend_p2p(bot_eopm.pin['b0'], right_mmi.pin['b0']).put()

    #part 4: add pins
    nd.Pin('a0', pin=left_mmi.pin['a0']).put()
    nd.Pin('b0', pin=right_mmi.pin['a0']).put()
    nd.Pin('c0', pin=top_eopm.pin['c0']).put()
    nd.Pin('c1', pin=bot_eopm.pin['c0']).put()


mzi = mziBB.put()
nd.export_plt(clear=False, title='1. MZI BB')

#add metal
adapt.bend(pin=mzi.pin['c0']).put()
adapt.strt(length=300).put()
adapt.bend(pin=mzi.pin['c1']).put()
adapt.strt(length=300).put()

#add guides
adapt.strt(length=100, pin=mzi.pin['a0']).put()
adapt.strt(length=100, pin=mzi.pin['b0']).put()

nd.export_plt(clear=False, title='2. MZI + connections')
nd.export_gds()
