# -*- coding: utf-8 -*-
"""
Demofab example-0

To view predefined layers in klayout load:
lyp_demo.lyp
"""
import nazca as nd
import nazca.demofab.pdk as demopdk
import nazca.demopackager.packages as demopackages


#==============================================================================
# Create and initialize die and package objects.
#==============================================================================
DIE = demopdk.DesignArea(name='die', coatingR='HR', coatingL='AR')
PACKAGE = demopackages.Package1(name='package1')


#==============================================================================
# Create a design project cell.
#==============================================================================
with nd.Cell(name='project') as project:

    # put the die and package cell
    die = DIE.cell().put(0)
    pack = PACKAGE.cell().put(0)

    # put the DCpads you need on pin defined by the package.
    dcTop = demopdk.bb_io_electrical.pad_dc().put('rc', pack.pin['dcT005'])
    dcBot = demopdk.bb_io_electrical.pad_dc().put('rc', pack.pin['dcB003'])

    # put optical IO cells you need
    ioL038 = demopdk.io(shape='angled', bend=True).put(die.pin['ioL038'])

    # Connect a straight waveguide and a SOA
    demopdk.bb_connectors.shallow.strt(500).put(ioL038.pin['b0'])
    soa1 = demopdk.bb_amplifiers.soa(length=650).put()

    # Connect the soa1 to the DC metal pads
    demopdk.bb_connectors.metaldc.sbend_p2p(\
        soa1.pin['c0'], dcTop.pin['c0'], Lstart=600).put()
    demopdk.bb_connectors.metaldc.sbend_p2p(\
        soa1.pin['c0'].rot(180), dcBot.pin['c0'], Lstart=500).put()


#==============================================================================
# Export project to GDS or Matplotlib
#==============================================================================
#nd.export_plt(project)
nd.export_gds(project, filename='project_example0b.gds')
