# -*- coding: utf-8 -*-
"""
Demofab example-1b

Add a xsection a package template cell and use those to automatically connect
the right BB.

To view predefined layers in klayout load:
lyp_demo.lyp
"""
import nazca as nd
import nazca.demofab.pdk as demopdk
import nazca.demopackager.packages as demopackages


#==============================================================================
# Create and initialize die and package objects.
#==============================================================================
DIE = demopdk.DesignArea(name='die', coatingR='HR', coatingL='AR')
PACKAGE = demopackages.Package1(name='package1')

# Create a cell based on DIE and package objects.
# This cell acts as your design template.
with nd.Cell('template') as template:

    # put the die cell and make all its pins available to 'template'
    die = DIE.cell().put(0)
    die.raise_pins()

    # put package cell and add building blocks on the pin or add pin attribites
    # add pins to the cell for external connections
    pack = PACKAGE.cell().put(0)
    for name, pin in pack.pin.items():
        if 'rf' in name:
            nd.Pin(name=name, xs='MetalRF').put(pin)
        elif 'dcT' in name:
            nd.Pin(name=name, xs='MetalDC').put(pin)
        elif 'dcB' in name:
            nd.Pin(name=name, xs='MetalDC').put(pin)
        else:
            nd.Pin(name=name, pin=pin).put()


#==============================================================================
# Create a design project cell.
#==============================================================================
with nd.Cell(name='project') as project:

    # Place your cell template
    T = template.put(0)

    io = {name: demopdk.presetio(pin=pin).put() for name, pin in T.pin.items()}

    print('IO pins:\n', sorted(io.keys()))
    # Connect a straight waveguide to the optical IO and add a SOA
    demopdk.bb_connectors.shallow.strt(500).put(io['ioL038'])
    soa1 = demopdk.bb_amplifiers.soa(length=650).put()

    #Connect the soa to DC metal pads
    demopdk.bb_connectors.metaldc.sbend_p2p(\
        soa1.pin['c0'], io['dcT003'], Lstart=600).put()
    demopdk.bb_connectors.metaldc.sbend_p2p(\
        soa1.pin['c0'].rot(180), io['dcB003'], Lstart=500).put()


#==============================================================================
# Export project to GDS
#==============================================================================
nd.export_gds(project, filename='project_example1b.gds')
