"""Demonstration of setting and using xsections and layers."""

import nazca as nd
import math as m


nd.set_plt_properties(figsize=10, cmap='jet', alpha=0.1)

#create a number of layers:
nd.add_layer('L1', layer=1, accuracy=1)
nd.add_layer('L2', layer=2, accuracy=0.01, alpha=0.1)
nd.add_layer('L3', layer=3)
nd.add_layer('L4', layer=4)

#customize layer colors
nd.set_layercolor(layer=1)
nd.set_layercolor(layer=1)
nd.set_layercolor(layer=2, datatype=0, fill_color='#FF0000')

#add layers to xsection (automatically add the xsections)
nd.add_layer2xsection(xsection='xs1', layer=1, growx=1)
nd.add_layer2xsection(xsection='xs1', layer=2, growx=5)
nd.add_layer2xsection(xsection='xs1', layer=3, growx=2)
nd.add_layer2xsection(xsection='xs1', layer=4, growx=8)
nd.add_layer2xsection(xsection='xs2', layer=2)
nd.add_layer2xsection(xsection='xs3', layer=3)
nd.add_layer2xsection(xsection='xs4', layer=4, accuracy=0.001)
nd.add_layer2xsection(xsection='xs4', layer=6, accuracy=0.1, growx=1)
nd.add_layer2xsection(xsection='xs5', layer=8)


nd.show_layers()
nd.show_layercolors()
nd.show_xsections()
nd.show_xsection_layer_map()
nd.show_mask_layers()


#draw waveguides and set xs on the fly:
nd.strt(length=50, xs='xs1').put()
nd.bend(xs='xs2').put()

#or create waveguide functions from templates
sw3 = nd.Tp_straight(xs='xs3')
sw4 = nd.Tp_straight(xs='xs4')
cw4 = nd.Tp_arc(xs='xs4')

#draw more waveguides:
sw3(length=20).put()
sw4(length=15).put()
cw4().put()

# Make width
sw3(length=20, xs='xs1',
    edge1=lambda t:2+m.sin(10*t)+3*t,
    edge2=lambda t:1+3*t*t).put() #overrule xs
sw3(width=8).put()


nd.export_plt()
