#-----------------------------------------------------------------------
# This file is part of Nazca.
#
# Nazca is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.
#
# Nazca is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Nazca.  If not, see <http://www.gnu.org/licenses/>.
#-----------------------------------------------------------------------
#
# Font specification
#
# (c) 2015 Xaveer Leijtens
#
# font: [0, character, [width, tuple of polylines].
from collections import defaultdict

f = {
'a': (((2, 3), (1, 3), (0, 2), (1, 1), (3, 1), (3, 3)),),
'b': (((1, 3), (2, 3), (3, 2), (2, 1), (0, 1), (0, 4)),),
'c': (((3, 1), (1, 1), (0, 2), (1, 3), (3, 3)),),
'd': (((3, 4), (3, 1), (1, 1), (0, 2), (1, 3), (2, 3)),),
'e': (((3, 1), (1, 1), (0, 1.5), (0, 2.5), (1, 3), (2, 3), (3, 2.5), (3, 2), (1, 2)),),
'f': (((0, 1), (0, 3.5), (0.5, 4), (1, 4)), ((0, 3), (1, 3)),),
'g': (((0, 0), (2, 0), (3, 0.5), (3, 3), (1, 3), (0, 2), (1, 1), (2, 1)),),
'h': (((0, 1), (0, 4)), ((0, 3), (2, 3), (3, 2), (3, 1)),),
'i': (((0, 4), (0, 3.8)), ((0, 3), (0, 1.5), (0.5, 1), (1, 1)),),
'j': (((0, 0), (0.5, 0), (1, 0.5), (1, 3)), ((1, 4), (1, 3.8)),),
'k': (((0, 1), (0, 4)), ((0, 2), (1, 2), (2, 3), (3, 3)), ((1, 2), (3, 1), (3, 1)),),
'l': (((0, 4), (0, 1.5), (0.5, 1), (1, 1)),),
'm': (((0, 1), (0, 3), (1, 3), (2, 2.5), (2, 1)), ((2, 2.5), (3, 3), (4, 2.5), (4, 1)),),
'n': (((0, 1), (0, 3), (2, 3), (3, 2.5), (3, 1)),),
'o': (((0, 2.25), (0, 2.5), (1, 3), (2, 3), (3, 2.5), (3, 2), (3, 1.5), (2, 1), (1, 1), (0, 1.5), (0, 1.75)),),
'p': (((0, 0), (0, 3), (2, 3), (3, 2), (2, 1), (1, 1)),),
'q': (((3, 0), (3, 3), (1, 3), (0, 2), (1, 1), (2, 1)),),
'r': (((0, 1), (0, 3), (2, 3), (3, 2.5)),),
's': (((0, 1), (2.5, 1), (3, 1.5), (2.5, 2), (0.5, 2), (0, 2.5), (0.5, 3), (3, 3)),),
't': (((0, 4), (0, 1.5), (0.5, 1), (1, 1)), ((0, 3), (1, 3)),),
'u': (((0, 3), (0, 1.5), (1, 1), (3, 1), (3, 3)),),
'v': (((0, 3), (0, 3), (1, 1), (2, 1), (3, 3), (3, 3)),),
'w': (((0, 3), (0, 1.5), (1, 1), (2, 1.5), (2, 3)), ((2, 1.5), (3, 1), (4, 1.5), (4, 3)),),
'x': (((0, 1), (0, 1), (1.2, 2), (1.8, 2), (3, 3), (3, 3)), ((0, 3), (0, 3), (1.2, 2), (1.8, 2), (3, 1), (3, 1)),),
'y': (((0, 3), (0, 1.5), (1, 1), (3, 1), (3, 3)), ((3, 1), (3, 0.5), (2, 0), (0, 0)),),
'z': (((3.24, 1), (0, 1), (0, 1.3), (3, 2.7), (3, 3), (-0.24, 3)),),
'A': (((0, 1), (0, 3.5), (1, 5), (3, 5), (4, 3.5), (4, 1)), ((4, 3), (2.8, 3)), ((1.2, 3), (0, 3)),),
'B': (((0, 3.5), (0, 5), (3, 5), (4, 4), (3, 3), (4, 2), (3, 1), (0, 1), (0, 2.5)), ((0.8, 3), (3, 3)),),
'C': (((4, 5), (1, 5), (0, 4), (0, 2), (1, 1), (4, 1)),),
'D': (((0, 3.5), (0, 5), (3, 5), (4, 4), (4, 2), (3, 1), (0, 1), (0, 2.5)),),
'E': (((4, 1), (0, 1), (0, 5), (4, 5)), ((0, 3), (3, 3)),),
'F': (((0, 1), (0, 5), (4, 5)), ((0, 3), (3, 3)),),
'G': (((4, 4), (3, 5), (1, 5), (0, 4), (0, 2), (1, 1), (3, 1), (4, 2), (4, 3), (2, 3)),),
'H': (((0, 1), (0, 5)), ((0, 3), (4, 3)), ((4, 1), (4, 5)),),
'I': (((0, 1), (2, 1)), ((1, 1), (1, 5)), ((0, 5), (2, 5)),),
'J': (((0, 2), (1, 1), (3, 1), (4, 2), (4, 5), (0, 5)),),
'K': (((0, 1), (0, 5)), ((0, 3), (1, 3), (4, 5), (4, 5)), ((1, 3), (4, 1), (4, 1)),),
'L': (((4, 1), (0, 1), (0, 5)),),
'M': (((0, 1), (0, 5), (0.55, 5), (1.75, 3), (2.25, 3), (3.45, 5), (4, 5), (4, 1)),),
'N': (((0, 1), (0, 5), (0.55, 5), (3.45, 1), (4, 1), (4, 5)),),
'O': (((0, 3.5), (0, 4), (1, 5), (3, 5), (4, 4), (4, 2), (3, 1), (1, 1), (0, 2), (0, 2.5)),),
'P': (((0, 1), (0, 5), (3, 5), (4, 4), (3, 3), (1, 3)),),
'Q': (((3.01, 1.01), (3, 1), (1, 1), (0, 2), (0, 4), (1, 5), (3, 5), (4, 4), (4, 2), (3.99, 1.99)), ((3, 1.8), (4, 1.2)),),
'R': (((0, 1), (0, 5), (3, 5), (4, 4), (3, 3), (1, 3)), ((3, 3), (4, 2), (4, 1)),),
'S': (((0, 1.5), (1, 1), (3, 1), (4, 2), (3, 3), (1, 3), (0, 4), (1, 5), (3, 5), (4, 4.5)),),
'T': (((0, 5), (4, 5)), ((2, 1), (2, 5)),),
'U': (((0, 5), (0, 2), (1, 1), (3, 1), (4, 2), (4, 5)),),
'V': (((0, 5), (0, 4), (1.5, 1), (2.5, 1), (4, 4), (4, 5)),),
'W': (((0, 5), (0, 1), (0.55, 1), (1.75, 3), (2.25, 3), (3.45, 1), (4, 1), (4, 5)),),
'X': (((0, 1), (0, 1), (2, 2.5), (2, 3.5), (4, 5), (4, 5)), ((0, 5), (0, 5), (2, 3.5), (2, 2.5), (4, 1), (4, 1)),),
'Y': (((2, 1), (2, 3)), ((0, 5), (0, 5), (1.75, 3), (2.25, 3), (4, 5), (4, 5)),),
'Z': (((4, 1), (0, 1), (0, 1.25), (4, 4.75), (4, 5), (0, 5)),),
'0': (((0, 3.5), (0, 4), (1, 5), (3, 5), (4, 4), (4, 2), (3, 1), (1, 1), (0, 2), (0, 2.4)), ((0, 2.3), (0.5, 2.3), (1.5, 2.75)), ((2.5, 3.25), (3.5, 3.7), (4, 3.7)),),
'1': (((0, 1), (4, 1)), ((2, 1), (2, 5), (1.5, 5), (0, 4)),),
'2': (((4, 1), (0, 1), (0, 1.25), (4, 3), (4, 4), (3, 5), (1, 5), (0, 4)),),
'3': (((0, 2), (1, 1), (3, 1), (4, 2), (3, 3), (4, 4), (3, 5), (1, 5), (0, 4)), ((3, 3), (1, 3)),),
'4': (((1, 5), (0, 3.25), (0, 3), (4, 3)), ((4, 1), (4, 5)),),
'5': (((4, 5), (0, 5), (0, 3), (3, 3), (4, 2), (3, 1), (0, 1)),),
'6': (((4, 4), (3, 5), (1, 5), (0, 4), (0, 2), (1, 1), (3, 1), (4, 2), (3, 3), (2, 3), (1, 3)),),
'7': (((0, 5), (4, 5), (4, 4.75), (2, 3.5), (2, 1)), ((1, 3), (3, 3)),),
'8': (((0.5, 3.5), (0, 4), (1, 5), (3, 5), (4, 4), (3, 3), (2, 3), (1, 3), (0, 2), (1, 1), (3, 1), (4, 2), (3.5, 2.5)),),
'9': (((0, 2), (1, 1), (3, 1), (4, 2), (4, 4), (3, 5), (1, 5), (0, 4), (1, 3), (3, 3)),),
'#': (((0, 2), (4, 2)), ((0, 4), (4, 4)), ((1, 1), (1, 2.5)), ((1, 3.5), (1, 5)), ((3, 1), (3, 5)),),
'$': (((0, 1.5), (1, 1), (3, 1), (4, 2), (3, 3), (1, 3), (0, 4), (1, 5), (3, 5), (4, 4.5)), ((2, 2), (2, 4)),),
'%': (((0, 1), (0, 1), (4, 5), (4, 5)), ((0, 4), (0, 5), (1.5, 5), (1.5, 4)), ((4, 2), (4, 1), (2.5, 1), (2.5, 2)),),
'(': (((1, 5), (1, 5), (0, 4), (0, 2), (1, 1), (1, 1)),),
')': (((0, 5), (0, 5), (1, 4), (1, 2), (0, 1), (0, 1)),),
'[': (((1, 5), (0, 5), (0, 1), (1, 1)),),
']': (((0, 5), (1, 5), (1, 1), (0, 1)),),
'+': (((0, 3), (4, 3)), ((2, 2), (2, 4)),),
'-': (((0, 3), (3, 3)),),
'_': (((0, 1), (4, 1)),),
'.': (((0, 1), (0, 1.2)),),
',': (((0, 0.5), (0.5, 1), (0.5, 1.2)),),
'!': (((0, 1), (0, 1.35)), ((0, 2), (0, 5)),),
'\\': (((4, 1), (0, 5)),),
'/': (((0, 1), (4, 5)),),
'*': (((0, 2), (1, 2.65), (1, 2.65), (2, 2)), ((0, 4), (1, 3.35), (1, 3.35), (2, 4)), ((0, 3), (2, 3)), ((1, 2.5), (1, 3.5)),),
'µ': (((0, 1), (2, 1), (3, 1.5), (3, 3)), ((0, -0), (0, 3)),),
'Λ': (((0, 1), (0, 1), (1.8, 5), (2.2, 5), (4, 1), (4, 1)),),
'|': (((0, 1), (0, 5)),),
'@': (((3, 1), (0, 1), (0, 4), (2, 4), (2, 2), (1, 2), (1, 3)),),
'=': (((0, 2), (4, 2)), ((0, 3), (4, 3)),),
':': (((0, 1), (0, 1.2)), ((0, 3), (0, 2.8)),),
';': (((0, 0.5), (0.5, 1), (0.5, 1.2)), ((0.5, 3), (0.5, 2.8)),),
'&': (((4, 1), (3.25, 2), (2.75, 2), (0.5, 4), (0.5, 4.5), (1.5, 4.5), (2, 4)), ((4, 3), (3.25, 2), (2.75, 2), (2, 1), (1, 1), (0, 1.5), (0, 2.5), (0.5, 2.75)),),
'€': (((4, 5), (2, 5), (1, 4), (1, 2), (2, 1), (4, 1)), ((0, 2.5), (3, 2.5)), ((0, 3.5), (3, 3.5)),),
'>': (((0, 1), (3, 3), (0, 5)),),
'<': (((3, 1), (0, 3), (3, 5)),),
'"': (((0, 5), (0, 4)), ((1, 5), (1, 4)),),
"'": (((0, 5), (0, 4)),),
'□': (((3, 2), (3, 1), (0, 1), (0, 4), (3, 4), (3, 3)),),
}

font = defaultdict(lambda: (3,(((3,2),(3,1),(0,1),(0,4),(3,4),(3,3)),))) # '□'

# Record the width of each character
for char, strokes in f.items():
    maxx = max(x for stroke in strokes for (x, y) in stroke)
    font[char] = maxx, strokes
font[' '] = 1, (), # space is special
